@@ -42,6 +42,7 @@ func TestKameletChange(t *testing.T) {
 	WithNewTestNamespace(t, func(ns string) {
 		operatorID := "camel-k-kamelet-change"
 		timerSource := "my-timer-source"
+
 		Expect(KamelInstallWithID(operatorID, ns).Execute()).To(Succeed())
 		Expect(CreateTimerKamelet(ns, timerSource)()).To(Succeed())
 		Expect(CreateKnativeChannel(ns, "messages")()).To(Succeed())
@@ -66,22 +67,15 @@ func TestKameletChange(t *testing.T) {
 			"trait.camel.apache.org/health.readiness-initial-delay": "10",
 		}
 
+		// Create the KameletBinding
 		Expect(BindKameletTo(ns, timerBinding, annotations, from, to, map[string]string{"message": "message is Hello"}, map[string]string{})()).To(Succeed())
 
-		Eventually(KameletBindingConditionStatus(ns, timerBinding, v1alpha1.KameletBindingConditionReady), TestTimeoutShort).Should(Equal(corev1.ConditionFalse))
-		Eventually(KameletBindingCondition(ns, timerBinding, v1alpha1.KameletBindingConditionReady), TestTimeoutMedium).Should(And(
-			WithTransform(KameletBindingConditionReason, Equal(v1.IntegrationConditionDeploymentProgressingReason)),
-			WithTransform(KameletBindingConditionMessage, Or(
-				Equal("0/1 updated replicas"),
-				Equal("0/1 ready replicas"),
-			))))
-
 		Eventually(IntegrationPodPhase(ns, timerBinding), TestTimeoutLong).Should(Equal(corev1.PodRunning))
 		Eventually(IntegrationConditionStatus(ns, "timer-binding", v1.IntegrationConditionReady), TestTimeoutShort).Should(Equal(corev1.ConditionTrue))
 		Eventually(IntegrationLogs(ns, "display"), TestTimeoutShort).Should(ContainSubstring("message is Hello"))
 
-		Eventually(KameletBindingConditionStatus(ns, timerBinding, v1alpha1.KameletBindingConditionReady), TestTimeoutShort).Should(Equal(corev1.ConditionTrue))
 		Eventually(KameletBindingCondition(ns, timerBinding, v1alpha1.KameletBindingConditionReady), TestTimeoutMedium).Should(And(
+			WithTransform(KameletBindingConditionStatusExtract, Equal(corev1.ConditionTrue)),
 			WithTransform(KameletBindingConditionReason, Equal(v1.IntegrationConditionDeploymentReadyReason)),
 			WithTransform(KameletBindingConditionMessage, Equal(fmt.Sprintf("1/1 ready replicas"))),
 		))
@@ -89,21 +83,13 @@ func TestKameletChange(t *testing.T) {
 		// Update the KameletBinding
 		Expect(BindKameletTo(ns, "timer-binding", annotations, from, to, map[string]string{"message": "message is Hi"}, map[string]string{})()).To(Succeed())
 
-		Eventually(KameletBindingConditionStatus(ns, timerBinding, v1alpha1.KameletBindingConditionReady), TestTimeoutShort).Should(Equal(corev1.ConditionFalse))
-		Eventually(KameletBindingCondition(ns, timerBinding, v1alpha1.KameletBindingConditionReady), TestTimeoutMedium).Should(And(
-			WithTransform(KameletBindingConditionReason, Equal(v1.IntegrationConditionDeploymentProgressingReason)),
-			WithTransform(KameletBindingConditionMessage, Or(
-				Equal("0/1 updated replicas"),
-				Equal("0/1 ready replicas"),
-			))))
-
 		Eventually(IntegrationPodPhase(ns, "timer-binding"), TestTimeoutLong).Should(Equal(corev1.PodRunning))
 		Eventually(IntegrationConditionStatus(ns, "timer-binding", v1.IntegrationConditionReady), TestTimeoutShort).Should(Equal(corev1.ConditionTrue))
 		Eventually(IntegrationLogs(ns, "display"), TestTimeoutShort).Should(ContainSubstring("message is Hi"))
 
-		Eventually(KameletBindingConditionStatus(ns, timerBinding, v1alpha1.KameletBindingConditionReady), TestTimeoutShort).Should(Equal(corev1.ConditionTrue))
 		Eventually(KameletBindingCondition(ns, timerBinding, v1alpha1.KameletBindingConditionReady), TestTimeoutMedium).
 			Should(And(
+				WithTransform(KameletBindingConditionStatusExtract, Equal(corev1.ConditionTrue)),
 				WithTransform(KameletBindingConditionReason, Equal(v1.IntegrationConditionDeploymentReadyReason)),
 				WithTransform(KameletBindingConditionMessage, Equal("1/1 ready replicas")),
 			))
