@@ -33,6 +33,7 @@ import (
 	"os"
 	"os/exec"
 	"reflect"
+	"regexp"
 	"runtime/debug"
 	"strings"
 	"testing"
@@ -92,10 +93,10 @@ const kubeConfigEnvVar = "KUBECONFIG"
 
 var TestTimeoutShort = 1 * time.Minute
 var TestTimeoutMedium = 5 * time.Minute
-var TestTimeoutLong = 10 * time.Minute
+var TestTimeoutLong = 15 * time.Minute
 
 // TestTimeoutVeryLong should be used only for testing native builds.
-var TestTimeoutVeryLong = 90 * time.Minute
+var TestTimeoutVeryLong = 60 * time.Minute
 
 var NoOlmOperatorImage string
 
@@ -108,13 +109,12 @@ func setTestLocus(t *testing.T) {
 	testLocus = t
 }
 
-//
 // Only panic the test if absolutely necessary and there is
 // no test locus. In most cases, the test should fail gracefully
 // using the test locus to error out and fail now.
-//
 func failTest(err error) {
 	if testLocus != nil {
+		testLocus.Helper()
 		testLocus.Error(err)
 		testLocus.FailNow()
 	} else {
@@ -228,10 +228,14 @@ func KamelInstall(namespace string, args ...string) *cobra.Command {
 }
 
 func KamelInstallWithID(operatorID string, namespace string, args ...string) *cobra.Command {
-	return KamelInstallWithContext(TestContext, operatorID, namespace, args...)
+	return kamelInstallWithContext(TestContext, operatorID, namespace, true, args...)
 }
 
-func KamelInstallWithContext(ctx context.Context, operatorID string, namespace string, args ...string) *cobra.Command {
+func KamelInstallWithIDAndKameletCatalog(operatorID string, namespace string, args ...string) *cobra.Command {
+	return kamelInstallWithContext(TestContext, operatorID, namespace, false, args...)
+}
+
+func kamelInstallWithContext(ctx context.Context, operatorID string, namespace string, skipKameletCatalog bool, args ...string) *cobra.Command {
 	var installArgs []string
 
 	globalTest := os.Getenv("CAMEL_K_FORCE_GLOBAL_TEST") == "true"
@@ -250,6 +254,10 @@ func KamelInstallWithContext(ctx context.Context, operatorID string, namespace s
 		installArgs = []string{"install", "-n", namespace, "--operator-id", operatorID}
 	}
 
+	if skipKameletCatalog {
+		installArgs = append(installArgs, "--operator-env-vars", "KAMEL_INSTALL_DEFAULT_KAMELETS=false")
+	}
+
 	logLevel := os.Getenv("CAMEL_K_TEST_LOG_LEVEL")
 	if len(logLevel) > 0 {
 		fmt.Printf("Setting log-level to %s\n", logLevel)
@@ -398,15 +406,16 @@ func Make(rule string, args ...string) *exec.Cmd {
 }
 
 func MakeWithContext(ctx context.Context, rule string, args ...string) *exec.Cmd {
-	makeArgs := os.Getenv("MAKE_ARGS")
+	makeArgs := os.Getenv("CAMEL_K_TEST_MAKE_ARGS")
 	defaultArgs := strings.Fields(makeArgs)
 	args = append(defaultArgs, args...)
 
-	makeDir := os.Getenv("MAKE_DIR")
+	defaultDir := "../../../../install"
+	makeDir := os.Getenv("CAMEL_K_TEST_MAKE_DIR")
 	if makeDir == "" {
-		makeDir = "../../../../install"
-	} else {
-		fmt.Printf("Using alternative make directory on path %s\n", makeDir)
+		makeDir = defaultDir
+	} else if makeDir != defaultDir {
+		fmt.Printf("Using alternative make directory on path: %s\n", makeDir)
 	}
 
 	if fi, e := os.Stat(makeDir); e != nil && os.IsNotExist(e) {
@@ -420,9 +429,9 @@ func MakeWithContext(ctx context.Context, rule string, args ...string) *exec.Cmd
 	return exec.Command("make", args...)
 }
 
-/*
-	Curryied utility functions for testing
-*/
+// =============================================================================
+// Curried utility functions for testing
+// =============================================================================
 
 func IntegrationLogs(ns, name string) func() string {
 	return func() string {
@@ -443,6 +452,17 @@ func IntegrationLogs(ns, name string) func() string {
 	}
 }
 
+// Retrieve the Logs from the Pod defined by its name in the given namespace ns. The number of lines numLines from the end of the logs to show.
+func TailedLogs(ns, name string, numLines int64) func() string {
+	return func() string {
+		options := corev1.PodLogOptions{
+			TailLines: pointer.Int64(numLines),
+		}
+
+		return Logs(ns, name, options)()
+	}
+}
+
 func Logs(ns, podName string, options corev1.PodLogOptions) func() string {
 	return func() string {
 		byteReader, err := TestClient().CoreV1().Pods(ns).GetLogs(podName, &options).Stream(TestContext)
@@ -658,6 +678,47 @@ func IntegrationConditionMessage(c *v1.IntegrationCondition) string {
 	return c.Message
 }
 
+func HealthCheckResponse(podRegexp string, healthName string) func(*v1.IntegrationCondition) *v1.HealthCheckResponse {
+	re := regexp.MustCompile(podRegexp)
+
+	return func(c *v1.IntegrationCondition) *v1.HealthCheckResponse {
+		if c == nil {
+			return nil
+		}
+
+		for p := range c.Pods {
+			if re.MatchString(c.Pods[p].Name) {
+				continue
+			}
+
+			for h := range c.Pods[p].Health {
+				if c.Pods[p].Health[h].Name == healthName {
+					return &c.Pods[p].Health[h]
+				}
+			}
+
+		}
+
+		return nil
+	}
+}
+
+func HealthCheckData(r *v1.HealthCheckResponse) (map[string]interface{}, error) {
+	if r == nil {
+		return nil, nil
+	}
+	if r.Data == nil {
+		return nil, nil
+	}
+
+	var data map[string]interface{}
+	if err := json.Unmarshal(r.Data, data); err != nil {
+		return nil, err
+	}
+
+	return data, nil
+}
+
 func IntegrationConditionStatus(ns string, name string, conditionType v1.IntegrationConditionType) func() corev1.ConditionStatus {
 	return func() corev1.ConditionStatus {
 		c := IntegrationCondition(ns, name, conditionType)()
@@ -707,8 +768,7 @@ func Nodes() func() []corev1.Node {
 				APIVersion: corev1.SchemeGroupVersion.String(),
 			},
 		}
-		err := TestClient().List(TestContext, nodes)
-		if err != nil {
+		if err := TestClient().List(TestContext, nodes); err != nil {
 			failTest(err)
 		}
 		return nodes.Items
@@ -761,9 +821,7 @@ func ServiceType(ns string, name string) func() corev1.ServiceType {
 	}
 }
 
-//
 // Find the service in the given namespace with the given type
-//
 func ServicesByType(ns string, svcType corev1.ServiceType) func() []corev1.Service {
 	return func() []corev1.Service {
 		svcs := []corev1.Service{}
@@ -824,12 +882,11 @@ func IntegrationCronJob(ns string, name string) func() *batchv1.CronJob {
 				APIVersion: batchv1.SchemeGroupVersion.String(),
 			},
 		}
-		err := TestClient().List(TestContext, &lst,
+		if err := TestClient().List(TestContext, &lst,
 			ctrl.InNamespace(ns),
 			ctrl.MatchingLabels{
 				"camel.apache.org/integration": name,
-			})
-		if err != nil {
+			}); err != nil {
 			failTest(err)
 		}
 		if len(lst.Items) == 0 {
@@ -913,6 +970,16 @@ func IntegrationSpecProfile(ns string, name string) func() v1.TraitProfile {
 	}
 }
 
+func IntegrationSpecSA(ns string, name string) func() string {
+	return func() string {
+		it := Integration(ns, name)()
+		if it == nil {
+			return ""
+		}
+		return it.Spec.ServiceAccountName
+	}
+}
+
 func IntegrationKit(ns string, name string) func() string {
 	return func() string {
 		it := Integration(ns, name)()
@@ -996,6 +1063,16 @@ func KameletBinding(ns string, name string) func() *v1alpha1.KameletBinding {
 	}
 }
 
+func KameletBindingPhase(ns string, name string) func() v1alpha1.KameletBindingPhase {
+	return func() v1alpha1.KameletBindingPhase {
+		klb := KameletBinding(ns, name)()
+		if klb == nil {
+			return ""
+		}
+		return klb.Status.Phase
+	}
+}
+
 func KameletBindingSpecReplicas(ns string, name string) func() *int32 {
 	return func() *int32 {
 		klb := KameletBinding(ns, name)()
@@ -1030,6 +1107,13 @@ func KameletBindingCondition(ns string, name string, conditionType v1alpha1.Kame
 	}
 }
 
+func KameletBindingConditionStatusExtract(c *v1alpha1.KameletBindingCondition) corev1.ConditionStatus {
+	if c == nil {
+		return ""
+	}
+	return c.Status
+}
+
 func KameletBindingConditionReason(c *v1alpha1.KameletBindingCondition) string {
 	if c == nil {
 		return ""
@@ -1262,12 +1346,11 @@ func AutogeneratedConfigmapsCount(ns string) func() int {
 				APIVersion: corev1.SchemeGroupVersion.String(),
 			},
 		}
-		err := TestClient().List(TestContext, &lst,
+		if err := TestClient().List(TestContext, &lst,
 			ctrl.InNamespace(ns),
 			ctrl.MatchingLabels{
 				kubernetes.ConfigMapAutogenLabel: "true",
-			})
-		if err != nil {
+			}); err != nil {
 			failTest(err)
 		}
 		return len(lst.Items)
@@ -1334,9 +1417,7 @@ func CreatePlainTextSecret(ns string, name string, data map[string]string) error
 	return TestClient().Create(TestContext, &sec)
 }
 
-//
 // Finds a secret in the given namespace by name or prefix of name
-//
 func SecretByName(ns string, prefix string) func() *corev1.Secret {
 	return func() *corev1.Secret {
 		secretList, err := TestClient().CoreV1().Secrets(ns).List(TestContext, metav1.ListOptions{})
@@ -1656,12 +1737,11 @@ func OperatorPod(ns string) func() *corev1.Pod {
 				APIVersion: v1.SchemeGroupVersion.String(),
 			},
 		}
-		err := TestClient().List(TestContext, &lst,
+		if err := TestClient().List(TestContext, &lst,
 			ctrl.InNamespace(namespace),
 			ctrl.MatchingLabels{
 				"camel.apache.org/component": "operator",
-			})
-		if err != nil {
+			}); err != nil {
 			failTest(err)
 		}
 		if len(lst.Items) == 0 {
@@ -1671,6 +1751,29 @@ func OperatorPod(ns string) func() *corev1.Pod {
 	}
 }
 
+// Find one Pod filtered by namespace ns and label app.kubernetes.io/name value appName.
+func Pod(ns string, appName string) func() (*corev1.Pod, error) {
+	return func() (*corev1.Pod, error) {
+		lst := corev1.PodList{
+			TypeMeta: metav1.TypeMeta{
+				Kind:       "Pod",
+				APIVersion: v1.SchemeGroupVersion.String(),
+			},
+		}
+		if err := TestClient().List(TestContext, &lst,
+			ctrl.InNamespace(ns),
+			ctrl.MatchingLabels{
+				"app.kubernetes.io/name": appName,
+			}); err != nil {
+			return nil, err
+		}
+		if len(lst.Items) == 0 {
+			return nil, nil
+		}
+		return &lst.Items[0], nil
+	}
+}
+
 func OperatorTryPodForceKill(ns string, timeSeconds int) {
 	pod := OperatorPod(ns)()
 	if pod != nil {
@@ -1706,11 +1809,10 @@ func ClusterRole() func() []rbacv1.ClusterRole {
 				APIVersion: rbacv1.SchemeGroupVersion.String(),
 			},
 		}
-		err := TestClient().List(TestContext, &lst,
+		if err := TestClient().List(TestContext, &lst,
 			ctrl.MatchingLabels{
 				"app": "camel-k",
-			})
-		if err != nil {
+			}); err != nil {
 			failTest(err)
 		}
 		if len(lst.Items) == 0 {
@@ -1728,12 +1830,11 @@ func Role(ns string) func() []rbacv1.Role {
 				APIVersion: rbacv1.SchemeGroupVersion.String(),
 			},
 		}
-		err := TestClient().List(TestContext, &lst,
+		if err := TestClient().List(TestContext, &lst,
 			ctrl.InNamespace(ns),
 			ctrl.MatchingLabels{
 				"app": "camel-k",
-			})
-		if err != nil {
+			}); err != nil {
 			failTest(err)
 		}
 		if len(lst.Items) == 0 {
@@ -1751,12 +1852,11 @@ func RoleBinding(ns string) func() *rbacv1.RoleBinding {
 				APIVersion: metav1.SchemeGroupVersion.String(),
 			},
 		}
-		err := TestClient().List(TestContext, &lst,
+		if err := TestClient().List(TestContext, &lst,
 			ctrl.InNamespace(ns),
 			ctrl.MatchingLabels{
 				"app": "camel-k",
-			})
-		if err != nil {
+			}); err != nil {
 			failTest(err)
 		}
 		if len(lst.Items) == 0 {
@@ -1774,12 +1874,11 @@ func ServiceAccount(ns, name string) func() *corev1.ServiceAccount {
 				APIVersion: corev1.SchemeGroupVersion.String(),
 			},
 		}
-		err := TestClient().List(TestContext, &lst,
+		if err := TestClient().List(TestContext, &lst,
 			ctrl.InNamespace(ns),
 			ctrl.MatchingLabels{
 				"app": "camel-k",
-			})
-		if err != nil {
+			}); err != nil {
 			failTest(err)
 		}
 		if len(lst.Items) == 0 {
@@ -1792,8 +1891,7 @@ func ServiceAccount(ns, name string) func() *corev1.ServiceAccount {
 func KameletList(ns string) func() []v1alpha1.Kamelet {
 	return func() []v1alpha1.Kamelet {
 		lst := v1alpha1.NewKameletList()
-		err := TestClient().List(TestContext, &lst, ctrl.InNamespace(ns))
-		if err != nil {
+		if err := TestClient().List(TestContext, &lst, ctrl.InNamespace(ns)); err != nil {
 			failTest(err)
 		}
 		return lst.Items
@@ -1993,11 +2091,15 @@ func CreateTimerKamelet(ns string, name string) func() error {
 	return CreateKamelet(ns, name, flow, props, nil)
 }
 
+// Deprecated:
+// Use KamelBind func instead
 func BindKameletTo(ns, name string, annotations map[string]string, from, to corev1.ObjectReference,
 	sourceProperties, sinkProperties map[string]string) func() error {
 	return BindKameletToWithErrorHandler(ns, name, annotations, from, to, sourceProperties, sinkProperties, nil)
 }
 
+// Deprecated:
+// Use KamelBind func instead
 func BindKameletToWithErrorHandler(ns, name string, annotations map[string]string, from, to corev1.ObjectReference,
 	sourceProperties, sinkProperties map[string]string, errorHandler map[string]interface{}) func() error {
 	return func() error {
@@ -2021,6 +2123,8 @@ func BindKameletToWithErrorHandler(ns, name string, annotations map[string]strin
 	}
 }
 
+// Deprecated:
+// Use KamelBind func instead
 func asTemplate(source map[string]interface{}) *v1alpha1.Template {
 	bytes, err := json.Marshal(source)
 	if err != nil {
@@ -2031,6 +2135,8 @@ func asTemplate(source map[string]interface{}) *v1alpha1.Template {
 	}
 }
 
+// Deprecated:
+// Use KamelBind func instead
 func asErrorHandlerSpec(source map[string]interface{}) *v1alpha1.ErrorHandlerSpec {
 	bytes, err := json.Marshal(source)
 	if err != nil {
@@ -2041,7 +2147,13 @@ func asErrorHandlerSpec(source map[string]interface{}) *v1alpha1.ErrorHandlerSpe
 	}
 }
 
+// Deprecated:
+// Use KamelBind func instead
 func asEndpointProperties(props map[string]string) *v1alpha1.EndpointProperties {
+	if props == nil {
+		return &v1alpha1.EndpointProperties{}
+	}
+
 	bytes, err := json.Marshal(props)
 	if err != nil {
 		failTest(err)
@@ -2066,21 +2178,21 @@ func AsTraitConfiguration(props map[string]string) *traitv1.Configuration {
 	Namespace testing functions
 */
 
-func NumPods(ns string) func() int {
-	return func() int {
+func Pods(ns string) func() []corev1.Pod {
+	return func() []corev1.Pod {
 		lst := corev1.PodList{
 			TypeMeta: metav1.TypeMeta{
 				Kind:       "Pod",
 				APIVersion: v1.SchemeGroupVersion.String(),
 			},
 		}
-		if err := TestClient().List(TestContext, &lst, ctrl.InNamespace(ns)); err != nil && k8serrors.IsUnauthorized(err) {
-			return 0
-		} else if err != nil {
-			log.Error(err, "Error while listing the pods")
-			return 0
+		if err := TestClient().List(TestContext, &lst, ctrl.InNamespace(ns)); err != nil {
+			if !k8serrors.IsUnauthorized(err) {
+				log.Error(err, "Error while listing the pods")
+			}
+			return nil
 		}
-		return len(lst.Items)
+		return lst.Items
 	}
 }
 
@@ -2223,13 +2335,18 @@ func deleteTestNamespace(t *testing.T, ns ctrl.Object) {
 	}
 
 	// Wait for all pods to be deleted
-	pods := NumPods(ns.GetName())()
-	for i := 0; pods > 0 && i < 60; i++ {
+	pods := Pods(ns.GetName())()
+	for i := 0; len(pods) > 0 && i < 60; i++ {
 		time.Sleep(1 * time.Second)
-		pods = NumPods(ns.GetName())()
+		pods = Pods(ns.GetName())()
 	}
-	if pods > 0 {
-		t.Logf("Warning: some pods are still running in namespace %q after deletion (%d)", ns.GetName(), pods)
+	if len(pods) > 0 {
+		names := []string{}
+		for _, pod := range pods {
+			names = append(names, pod.Name)
+		}
+		t.Logf("Warning: some pods are still running in namespace %q after deletion", ns.GetName())
+		t.Logf("Warning: %d running pods: %s", len(pods), names)
 	}
 }
 
@@ -2354,3 +2471,24 @@ func GetOutputStringAsync(cmd *cobra.Command) func() string {
 		return buffer.String()
 	}
 }
+
+func CreateLogKamelet(ns string, name string) func() error {
+	flow := map[string]interface{}{
+		"from": map[string]interface{}{
+			"uri": "kamelet:source",
+			"steps": []map[string]interface{}{
+				{
+					"to": "log:{{loggerName}}",
+				},
+			},
+		},
+	}
+
+	props := map[string]v1alpha1.JSONSchemaProp{
+		"loggerName": {
+			Type: "string",
+		},
+	}
+
+	return CreateKamelet(ns, name, flow, props, nil)
+}
