@@ -262,6 +262,8 @@ type IntegrationCondition struct {
 	Reason string `json:"reason,omitempty"`
 	// A human-readable message indicating details about the transition.
 	Message string `json:"message,omitempty"`
+	// Pods collect health and conditions information from the owned PODs
+	Pods []PodCondition `json:"pods,omitempty"`
 }
 
 // PodSpecTemplate represent a template used to deploy an Integration `Pod`
@@ -295,3 +297,9 @@ type PodSpec struct {
 	// PodSecurityContext
 	SecurityContext corev1.PodSecurityContext `json:"securityContext,omitempty" protobuf:"bytes,34,opt,name=securityContext"`
 }
+
+type PodCondition struct {
+	Name      string                `json:"name,omitempty" yaml:"name,omitempty"`
+	Condition corev1.PodCondition   `json:"condition" yaml:"condition"`
+	Health    []HealthCheckResponse `json:"health,omitempty" yaml:"health,omitempty"`
+}
