@@ -21,6 +21,9 @@ import (
 	"strings"
 	"time"
 
+	"golang.org/x/text/cases"
+	"golang.org/x/text/language"
+
 	"github.com/spf13/cobra"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -60,10 +63,10 @@ func describeTraits(w *indentedwriter.Writer, traits interface{}) error {
 		w.Writef(0, "Traits:\n")
 
 		for id, trait := range traitMap {
-			w.Writef(1, "%s:\n", strings.Title(id))
+			w.Writef(1, "%s:\n", cases.Title(language.English).String(id))
 			// TODO: print the whole TraitSpec as Yaml
 			for k, v := range trait {
-				w.Writef(2, "%s:\t%v\n", strings.Title(k), v)
+				w.Writef(2, "%s:\t%v\n", cases.Title(language.English).String(k), v)
 			}
 		}
 	}
