@@ -153,15 +153,6 @@ func newCmdInstall(rootCmdOptions *RootCmdOptions) (*cobra.Command, *installCmdO
 	// save
 	cmd.Flags().Bool("save", false, "Save the install parameters into the default kamel configuration file (kamel-config.yaml)")
 
-	// completion support
-	configureBashAnnotationForFlag(
-		&cmd,
-		"context",
-		map[string][]string{
-			cobra.BashCompCustom: {"__kamel_kubectl_get_known_integrationcontexts"},
-		},
-	)
-
 	return &cmd, &options
 }
 
@@ -215,16 +206,53 @@ type installCmdOptions struct {
 	olmOptions olm.Options
 }
 
-// nolint: gocyclo,maintidx // TODO: refactor the code
-func (o *installCmdOptions) install(cobraCmd *cobra.Command, _ []string) error {
-	var collection *kubernetes.Collection
+func (o *installCmdOptions) install(cmd *cobra.Command, _ []string) error {
+	var output *kubernetes.Collection
 	if o.OutputFormat != "" {
-		collection = kubernetes.NewCollection()
+		output = kubernetes.NewCollection()
 	}
 
 	// Let's use a client provider during cluster installation, to eliminate the problem of CRD object caching
 	clientProvider := client.Provider{Get: o.NewCmdClient}
 
+	o.setupEnvVars()
+
+	installViaOLM := false
+	if o.Olm {
+		installed, err := o.tryInstallViaOLM(cmd, clientProvider, output)
+		if err != nil {
+			return err
+		}
+		installViaOLM = installed
+	}
+
+	if !o.SkipClusterSetup && !installViaOLM {
+		if err := install.SetupClusterWideResourcesOrCollect(o.Context, clientProvider,
+			output, o.ClusterType, o.Force); err != nil {
+			if k8serrors.IsForbidden(err) {
+				fmt.Fprintln(cmd.OutOrStdout(),
+					"Current user is not authorized to create cluster-wide objects like custom resource definitions or cluster roles:",
+					err)
+				msg := `please login as cluster-admin and execute "kamel install --cluster-setup" to install cluster-wide resources (one-time operation)`
+				return errors.New(msg)
+			}
+			return err
+		}
+	}
+
+	if o.ClusterSetupOnly {
+		if output != nil {
+			return o.printOutput(cmd, output)
+		}
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K cluster setup completed successfully")
+		return nil
+	}
+
+	return o.installOperator(cmd, output, installViaOLM)
+}
+
+// setupEnvVars sets up additional env vars from the command options.
+func (o *installCmdOptions) setupEnvVars() {
 	// --operator-id={id} is a syntax sugar for '--operator-env-vars KAMEL_OPERATOR_ID={id}'
 	o.EnvVars = append(o.EnvVars, fmt.Sprintf("KAMEL_OPERATOR_ID=%s", strings.TrimSpace(o.OperatorID)))
 
@@ -237,320 +265,121 @@ func (o *installCmdOptions) install(cobraCmd *cobra.Command, _ []string) error {
 	if len(o.LogLevel) > 0 {
 		o.EnvVars = append(o.EnvVars, fmt.Sprintf("LOG_LEVEL=%s", strings.TrimSpace(o.LogLevel)))
 	}
+}
 
-	installViaOLM := false
-	if o.Olm {
-		var err error
-		var olmClient client.Client
-		if olmClient, err = clientProvider.Get(); err != nil {
-			return err
-		}
-		var olmAvailable bool
-		if olmAvailable, err = olm.IsAPIAvailable(o.Context, olmClient, o.Namespace); err != nil {
-			return errors.Wrap(err, "error while checking OLM availability. Run with '--olm=false' to skip this check")
-		}
-		if olmAvailable {
-			if installViaOLM, err = olm.HasPermissionToInstall(o.Context, olmClient, o.Namespace, o.Global, o.olmOptions); err != nil {
-				return errors.Wrap(err, "error while checking permissions to install operator via OLM. Run with '--olm=false' to skip this check")
-			}
-			if !installViaOLM {
-				fmt.Fprintln(cobraCmd.OutOrStdout(), "OLM is available but current user has not enough permissions to create the operator. "+
-					"You can either ask your administrator to provide permissions (preferred) or run the install command with the `--olm=false` flag.")
-				os.Exit(1)
+func (o *installCmdOptions) tryInstallViaOLM(
+	cmd *cobra.Command, clientProvider client.Provider, output *kubernetes.Collection,
+) (bool, error) {
+	olmClient, err := clientProvider.Get()
+	if err != nil {
+		return false, err
+	}
+	if olmAvailable, err := olm.IsAPIAvailable(o.Context, olmClient, o.Namespace); err != nil {
+		return false, errors.Wrap(err,
+			"error while checking OLM availability. Run with '--olm=false' to skip this check")
+	} else if !olmAvailable {
+		fmt.Fprintln(cmd.OutOrStdout(), "OLM is not available in the cluster. Fallback to regular installation.")
+		return false, nil
+	}
+
+	if hasPermission, err := olm.HasPermissionToInstall(o.Context, olmClient,
+		o.Namespace, o.Global, o.olmOptions); err != nil {
+		return false, errors.Wrap(err,
+			"error while checking permissions to install operator via OLM. Run with '--olm=false' to skip this check")
+	} else if !hasPermission {
+		return false, errors.New(
+			"OLM is available but current user has not enough permissions to create the operator. " +
+				"You can either ask your administrator to provide permissions (preferred) " +
+				"or run the install command with the '--olm=false' flag.")
+	}
+
+	// Install or collect via OLM
+	fmt.Fprintln(cmd.OutOrStdout(), "OLM is available in the cluster")
+	if installed, err := olm.Install(o.Context, olmClient, o.Namespace, o.Global, o.olmOptions, output,
+		o.Tolerations, o.NodeSelectors, o.ResourcesRequirements, o.EnvVars); err != nil {
+		return false, err
+	} else if !installed {
+		fmt.Fprintln(cmd.OutOrStdout(), "OLM resources are already available; skipping installation")
+	}
+
+	if err := install.WaitForAllCrdInstallation(o.Context, clientProvider, 90*time.Second); err != nil {
+		return false, err
+	}
+
+	return true, nil
+}
+
+func (o *installCmdOptions) installOperator(cmd *cobra.Command, output *kubernetes.Collection, olm bool) error {
+	operatorID, err := getOperatorID(o.EnvVars)
+	if err != nil {
+		return err
+	}
+
+	c, err := o.GetCmdClient()
+	if err != nil {
+		return err
+	}
+
+	namespace := o.Namespace
+
+	var platformName string
+	if operatorID != "" {
+		platformName = operatorID
+	} else {
+		platformName = platformutil.DefaultPlatformName
+	}
+
+	// Set up operator
+	if !olm {
+		if !o.SkipOperatorSetup {
+			if err := o.setupOperator(cmd, c, namespace, platformName, output); err != nil {
+				return err
 			}
 		} else {
-			fmt.Fprintln(cobraCmd.OutOrStdout(), "OLM is not available in the cluster. Fallback to regular installation.")
-		}
-
-		if installViaOLM {
-			fmt.Fprintln(cobraCmd.OutOrStdout(), "OLM is available in the cluster")
-			var installed bool
-			if installed, err = olm.Install(o.Context, olmClient, o.Namespace, o.Global, o.olmOptions, collection,
-				o.Tolerations, o.NodeSelectors, o.ResourcesRequirements, o.EnvVars); err != nil {
-				return err
-			}
-			if !installed {
-				fmt.Fprintln(cobraCmd.OutOrStdout(), "OLM resources are already available: skipping installation")
-			}
-
-			if err = install.WaitForAllCrdInstallation(o.Context, clientProvider, 90*time.Second); err != nil {
-				return err
-			}
+			fmt.Fprintln(cmd.OutOrStdout(), "Camel K operator installation skipped")
 		}
 	}
 
-	if !o.SkipClusterSetup && !installViaOLM {
-		err := install.SetupClusterWideResourcesOrCollect(o.Context, clientProvider, collection, o.ClusterType, o.Force)
-		if err != nil && k8serrors.IsForbidden(err) {
-			fmt.Fprintln(cobraCmd.OutOrStdout(), "Current user is not authorized to create cluster-wide objects like custom resource definitions or cluster roles: ", err)
-
-			meg := `please login as cluster-admin and execute "kamel install --cluster-setup" to install cluster-wide resources (one-time operation)`
-			return errors.New(meg)
-		} else if err != nil {
+	// Set up registry secret
+	registrySecretName := ""
+	if !o.SkipRegistrySetup {
+		registrySecretName, err = o.setupRegistrySecret(c, namespace, output)
+		if err != nil {
 			return err
 		}
-	}
-
-	if o.ClusterSetupOnly {
-		if collection == nil {
-			fmt.Fprintln(cobraCmd.OutOrStdout(), "Camel K cluster setup completed successfully")
-		}
 	} else {
-		operatorID, err := getOperatorID(o.EnvVars)
-		if err != nil {
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K operator registry setup skipped")
+	}
+
+	// Set up IntegrationPlatform
+	platform, err := o.setupIntegrationPlatform(cmd, c, namespace, platformName, registrySecretName, output)
+	if err != nil {
+		return err
+	}
+
+	if output != nil {
+		return o.printOutput(cmd, output)
+	}
+
+	if o.Wait {
+		if err := o.waitForPlatformReady(cmd, platform); err != nil {
 			return err
 		}
-
-		c, err := o.GetCmdClient()
-		if err != nil {
-			return err
-		}
-
-		namespace := o.Namespace
-
-		var platformName string
-		if operatorID != "" {
-			platformName = operatorID
-		} else {
-			platformName = platformutil.DefaultPlatformName
-		}
-
-		if !o.SkipOperatorSetup && !installViaOLM {
-			if ok, err := isInstallAllowed(o.Context, c, platformName, o.Force, cobraCmd.OutOrStdout()); err != nil {
-				if k8serrors.IsForbidden(err) {
-					o.PrintfVerboseOutf(cobraCmd, "Unable to verify existence of operator id [%s] due to lack of user privileges\n", platformName)
-				} else {
-					return err
-				}
-			} else if !ok {
-				return fmt.Errorf("installation not allowed because operator with id '%s' already exists, use the --force option to skip this check", platformName)
-			}
-
-			cfg := install.OperatorConfiguration{
-				CustomImage:           o.OperatorImage,
-				CustomImagePullPolicy: o.OperatorImagePullPolicy,
-				Namespace:             namespace,
-				Global:                o.Global,
-				ClusterType:           o.ClusterType,
-				Health: install.OperatorHealthConfiguration{
-					Port: o.HealthPort,
-				},
-				Monitoring: install.OperatorMonitoringConfiguration{
-					Enabled: o.Monitoring,
-					Port:    o.MonitoringPort,
-				},
-				Tolerations:           o.Tolerations,
-				NodeSelectors:         o.NodeSelectors,
-				ResourcesRequirements: o.ResourcesRequirements,
-				EnvVars:               o.EnvVars,
-			}
-			err = install.OperatorOrCollect(o.Context, cobraCmd, c, cfg, collection, o.Force)
-			if err != nil {
-				return err
-			}
-		} else if o.SkipOperatorSetup {
-			fmt.Fprintln(cobraCmd.OutOrStdout(), "Camel K operator installation skipped")
-		}
-
-		generatedSecretName := ""
-
-		if !o.SkipRegistrySetup {
-			if o.registryAuth.IsSet() {
-				regData := o.registryAuth
-				regData.Registry = o.registry.Address
-				generatedSecretName, err = install.RegistrySecretOrCollect(o.Context, c, namespace, regData, collection, o.Force)
-				if err != nil {
-					return err
-				}
-			} else if o.RegistryAuthFile != "" {
-				generatedSecretName, err = install.RegistrySecretFromFileOrCollect(o.Context, c, namespace, o.RegistryAuthFile, collection, o.Force)
-				if err != nil {
-					return err
-				}
-			}
-		} else if o.SkipRegistrySetup {
-			fmt.Fprintln(cobraCmd.OutOrStdout(), "Camel K operator registry setup skipped")
-		}
-
-		platform, err := install.NewPlatform(o.Context, c, o.ClusterType, o.SkipRegistrySetup, o.registry, platformName)
-		if err != nil {
-			return err
-		}
-
-		if generatedSecretName != "" {
-			platform.Spec.Build.Registry.Secret = generatedSecretName
-		}
-
-		if len(o.MavenProperties) > 0 {
-			platform.Spec.Build.Maven.Properties = make(map[string]string)
-			for _, property := range o.MavenProperties {
-				kv := strings.Split(property, "=")
-				if len(kv) == 2 {
-					platform.Spec.Build.Maven.Properties[kv[0]] = kv[1]
-				}
-			}
-		}
-
-		if size := len(o.MavenExtensions); size > 0 {
-			platform.Spec.Build.Maven.Extension = make([]v1.MavenArtifact, 0, size)
-			for _, extension := range o.MavenExtensions {
-				gav := strings.Split(extension, ":")
-				if len(gav) != 2 && len(gav) != 3 {
-					meg := fmt.Sprintf("Maven build extension GAV must match <groupId>:<artifactId>:<version>, found: %s", extension)
-					return errors.New(meg)
-				}
-				ext := v1.MavenArtifact{
-					GroupID:    gav[0],
-					ArtifactID: gav[1],
-				}
-				if len(gav) == 3 {
-					ext.Version = gav[2]
-				}
-				platform.Spec.Build.Maven.Extension = append(platform.Spec.Build.Maven.Extension, ext)
-			}
-		}
-
-		if o.MavenLocalRepository != "" {
-			platform.Spec.Build.Maven.LocalRepository = o.MavenLocalRepository
-		}
-
-		if len(o.MavenCLIOptions) > 0 {
-			platform.Spec.Build.Maven.CLIOptions = o.MavenCLIOptions
-		}
-
-		if o.RuntimeVersion != "" {
-			platform.Spec.Build.RuntimeVersion = o.RuntimeVersion
-		}
-		if o.BaseImage != "" {
-			platform.Spec.Build.BaseImage = o.BaseImage
-		}
-		if o.BuildStrategy != "" {
-			platform.Spec.Build.BuildStrategy = v1.BuildStrategy(o.BuildStrategy)
-		}
-		if o.BuildPublishStrategy != "" {
-			platform.Spec.Build.PublishStrategy = v1.IntegrationPlatformBuildPublishStrategy(o.BuildPublishStrategy)
-		}
-		if o.BuildTimeout != "" {
-			d, err := time.ParseDuration(o.BuildTimeout)
-			if err != nil {
-				return err
-			}
-
-			platform.Spec.Build.Timeout = &metav1.Duration{
-				Duration: d,
-			}
-		}
-		if o.TraitProfile != "" {
-			platform.Spec.Profile = v1.TraitProfileByName(o.TraitProfile)
-		}
-
-		if len(o.MavenRepositories) > 0 {
-			settings, err := maven.NewSettings(maven.Repositories(o.MavenRepositories...), maven.DefaultRepositories)
-
-			if err != nil {
-				return err
-			}
-			err = createDefaultMavenSettingsConfigMap(o.Context, c, namespace, platform.Name, settings)
-			if err != nil {
-				return err
-			}
-			platform.Spec.Build.Maven.Settings.ConfigMapKeyRef = &corev1.ConfigMapKeySelector{
-				LocalObjectReference: corev1.LocalObjectReference{
-					Name: platform.Name + "-maven-settings",
-				},
-				Key: "settings.xml",
-			}
-		}
-
-		if o.MavenSettings != "" {
-			mavenSettings, err := decodeMavenSettings(o.MavenSettings)
-			if err != nil {
-				return err
-			}
-			platform.Spec.Build.Maven.Settings = mavenSettings
-		}
-
-		if o.MavenCASecret != "" {
-			secret, err := decodeSecretKeySelector(o.MavenCASecret)
-			if err != nil {
-				return err
-			}
-			platform.Spec.Build.Maven.CASecrets = append(platform.Spec.Build.Maven.CASecrets, *secret)
-		}
-
-		if o.ClusterType != "" {
-			for _, c := range v1.AllIntegrationPlatformClusters {
-				if strings.EqualFold(string(c), o.ClusterType) {
-					platform.Spec.Cluster = c
-				}
-			}
-		}
-		if platform.Spec.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyKaniko && cobraCmd.Flags().Lookup("kaniko-build-cache").Changed {
-			fmt.Fprintln(cobraCmd.OutOrStdout(), "Warn: the flag --kaniko-build-cache is deprecated, use --build-publish-strategy-option KanikoBuildCacheEnabled=true instead")
-			platform.Spec.Build.AddOption(builder.KanikoBuildCacheEnabled, strconv.FormatBool(o.KanikoBuildCache))
-		}
-		if len(o.BuildPublishStrategyOptions) > 0 {
-			if err = o.addBuildPublishStrategyOptions(&platform.Spec.Build); err != nil {
-				return err
-			}
-		}
-		// Always create a platform in the namespace where the operator is located
-		err = install.ObjectOrCollect(o.Context, c, namespace, collection, o.Force, platform)
-		if err != nil {
-			return err
-		}
-
-		if err := install.IntegrationPlatformViewerRole(o.Context, c, namespace); err != nil && !k8serrors.IsAlreadyExists(err) {
-			return errors.Wrap(err, "Error while installing global IntegrationPlatform viewer role")
-		}
-
-		if o.ExampleSetup {
-			err = install.ExampleOrCollect(o.Context, c, namespace, collection, o.Force)
-			if err != nil {
-				return err
-			}
-		}
-
-		if collection == nil {
-			if o.Wait {
-				err = o.waitForPlatformReady(cobraCmd, platform)
-				if err != nil {
-					return err
-				}
-			}
-
-			strategy := ""
-			if installViaOLM {
-				strategy = "via OLM subscription"
-			}
-			if o.Global {
-				fmt.Fprintln(cobraCmd.OutOrStdout(), "Camel K installed in namespace", namespace, strategy, "(global mode)")
-			} else {
-				fmt.Fprintln(cobraCmd.OutOrStdout(), "Camel K installed in namespace", namespace, strategy)
-			}
-		}
 	}
 
-	if collection != nil {
-		return o.printOutput(cobraCmd, collection)
+	strategy := ""
+	if olm {
+		strategy = "via OLM subscription"
+	}
+	if o.Global {
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K installed in namespace", namespace, strategy, "(global mode)")
+	} else {
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K installed in namespace", namespace, strategy)
 	}
 
 	return nil
 }
 
-func isInstallAllowed(ctx context.Context, c client.Client, operatorID string, force bool, out io.Writer) (bool, error) {
-	// find existing platform with given name in any namespace
-	pl, err := platformutil.LookupForPlatformName(ctx, c, operatorID)
-
-	if pl != nil && force {
-		fmt.Fprintf(out, "Overwriting existing operator with id '%s'\n", operatorID)
-		return true, nil
-	}
-
-	// only allow installation when platform with given name is not found
-	return pl == nil, err
-}
-
 func getOperatorID(vars []string) (string, error) {
 	envs, _, _, err := env.ParseEnv(vars, nil)
 	if err != nil {
@@ -565,19 +394,213 @@ func getOperatorID(vars []string) (string, error) {
 	return "", nil
 }
 
-func (o *installCmdOptions) postRun(cmd *cobra.Command, _ []string) error {
-	if o.Save {
-		cfg, err := LoadConfiguration()
-		if err != nil {
+func (o *installCmdOptions) setupOperator(
+	cmd *cobra.Command, c client.Client, namespace string, platformName string, output *kubernetes.Collection,
+) error {
+	if ok, err := isInstallAllowed(o.Context, c, platformName, o.Force, cmd.OutOrStdout()); err != nil {
+		if k8serrors.IsForbidden(err) {
+			o.PrintfVerboseOutf(cmd,
+				"Unable to verify existence of operator id %q due to lack of user privileges\n",
+				platformName)
+		} else {
 			return err
 		}
-
-		cfg.Update(cmd, pathToRoot(cmd), o, true)
-
-		return cfg.Save()
+	} else if !ok {
+		return fmt.Errorf(
+			"installation not allowed because operator with id %q already exists; use the --force option to skip this check",
+			platformName)
 	}
 
-	return nil
+	cfg := install.OperatorConfiguration{
+		CustomImage:           o.OperatorImage,
+		CustomImagePullPolicy: o.OperatorImagePullPolicy,
+		Namespace:             namespace,
+		Global:                o.Global,
+		ClusterType:           o.ClusterType,
+		Health: install.OperatorHealthConfiguration{
+			Port: o.HealthPort,
+		},
+		Monitoring: install.OperatorMonitoringConfiguration{
+			Enabled: o.Monitoring,
+			Port:    o.MonitoringPort,
+		},
+		Tolerations:           o.Tolerations,
+		NodeSelectors:         o.NodeSelectors,
+		ResourcesRequirements: o.ResourcesRequirements,
+		EnvVars:               o.EnvVars,
+	}
+
+	return install.OperatorOrCollect(o.Context, cmd, c, cfg, output, o.Force)
+}
+
+func isInstallAllowed(ctx context.Context, c client.Client, operatorID string, force bool, out io.Writer) (bool, error) {
+	// find existing platform with given name in any namespace
+	pl, err := platformutil.LookupForPlatformName(ctx, c, operatorID)
+
+	if pl != nil && force {
+		fmt.Fprintf(out, "Overwriting existing operator with id %q\n", operatorID)
+		return true, nil
+	}
+
+	// only allow installation when platform with given name is not found
+	return pl == nil, err
+}
+
+func (o *installCmdOptions) setupRegistrySecret(c client.Client, namespace string, output *kubernetes.Collection) (string, error) {
+	if o.registryAuth.IsSet() {
+		regData := o.registryAuth
+		regData.Registry = o.registry.Address
+		return install.RegistrySecretOrCollect(o.Context, c, namespace, regData, output, o.Force)
+	} else if o.RegistryAuthFile != "" {
+		return install.RegistrySecretFromFileOrCollect(o.Context, c, namespace, o.RegistryAuthFile, output, o.Force)
+	}
+
+	return "", nil
+}
+
+func (o *installCmdOptions) setupIntegrationPlatform(
+	cmd *cobra.Command, c client.Client, namespace string, platformName string, registrySecretName string,
+	output *kubernetes.Collection,
+) (*v1.IntegrationPlatform, error) {
+	platform, err := install.NewPlatform(o.Context, c, o.ClusterType, o.SkipRegistrySetup, o.registry, platformName)
+	if err != nil {
+		return nil, err
+	}
+
+	if registrySecretName != "" {
+		platform.Spec.Build.Registry.Secret = registrySecretName
+	}
+
+	if len(o.MavenProperties) > 0 {
+		platform.Spec.Build.Maven.Properties = make(map[string]string)
+		for _, property := range o.MavenProperties {
+			kv := strings.Split(property, "=")
+			if len(kv) == 2 {
+				platform.Spec.Build.Maven.Properties[kv[0]] = kv[1]
+			}
+		}
+	}
+
+	if size := len(o.MavenExtensions); size > 0 {
+		platform.Spec.Build.Maven.Extension = make([]v1.MavenArtifact, 0, size)
+		for _, extension := range o.MavenExtensions {
+			gav := strings.Split(extension, ":")
+			if len(gav) != 2 && len(gav) != 3 {
+				msg := fmt.Sprintf("Maven build extension GAV must match <groupId>:<artifactId>:<version>, found: %s", extension)
+				return nil, errors.New(msg)
+			}
+			ext := v1.MavenArtifact{
+				GroupID:    gav[0],
+				ArtifactID: gav[1],
+			}
+			if len(gav) == 3 {
+				ext.Version = gav[2]
+			}
+			platform.Spec.Build.Maven.Extension = append(platform.Spec.Build.Maven.Extension, ext)
+		}
+	}
+
+	if o.MavenLocalRepository != "" {
+		platform.Spec.Build.Maven.LocalRepository = o.MavenLocalRepository
+	}
+
+	if len(o.MavenCLIOptions) > 0 {
+		platform.Spec.Build.Maven.CLIOptions = o.MavenCLIOptions
+	}
+
+	if o.RuntimeVersion != "" {
+		platform.Spec.Build.RuntimeVersion = o.RuntimeVersion
+	}
+	if o.BaseImage != "" {
+		platform.Spec.Build.BaseImage = o.BaseImage
+	}
+	if o.BuildStrategy != "" {
+		platform.Spec.Build.BuildStrategy = v1.BuildStrategy(o.BuildStrategy)
+	}
+	if o.BuildPublishStrategy != "" {
+		platform.Spec.Build.PublishStrategy = v1.IntegrationPlatformBuildPublishStrategy(o.BuildPublishStrategy)
+	}
+	if o.BuildTimeout != "" {
+		d, err := time.ParseDuration(o.BuildTimeout)
+		if err != nil {
+			return nil, err
+		}
+
+		platform.Spec.Build.Timeout = &metav1.Duration{
+			Duration: d,
+		}
+	}
+	if o.TraitProfile != "" {
+		platform.Spec.Profile = v1.TraitProfileByName(o.TraitProfile)
+	}
+
+	if len(o.MavenRepositories) > 0 {
+		settings, err := maven.NewSettings(maven.Repositories(o.MavenRepositories...), maven.DefaultRepositories)
+		if err != nil {
+			return nil, err
+		}
+		err = createDefaultMavenSettingsConfigMap(o.Context, c, namespace, platform.Name, settings)
+		if err != nil {
+			return nil, err
+		}
+		platform.Spec.Build.Maven.Settings.ConfigMapKeyRef = &corev1.ConfigMapKeySelector{
+			LocalObjectReference: corev1.LocalObjectReference{
+				Name: platform.Name + "-maven-settings",
+			},
+			Key: "settings.xml",
+		}
+	}
+
+	if o.MavenSettings != "" {
+		mavenSettings, err := decodeMavenSettings(o.MavenSettings)
+		if err != nil {
+			return nil, err
+		}
+		platform.Spec.Build.Maven.Settings = mavenSettings
+	}
+
+	if o.MavenCASecret != "" {
+		secret, err := decodeSecretKeySelector(o.MavenCASecret)
+		if err != nil {
+			return nil, err
+		}
+		platform.Spec.Build.Maven.CASecrets = append(platform.Spec.Build.Maven.CASecrets, *secret)
+	}
+
+	if o.ClusterType != "" {
+		for _, c := range v1.AllIntegrationPlatformClusters {
+			if strings.EqualFold(string(c), o.ClusterType) {
+				platform.Spec.Cluster = c
+			}
+		}
+	}
+	if platform.Spec.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyKaniko && cmd.Flags().Lookup("kaniko-build-cache").Changed {
+		fmt.Fprintln(cmd.OutOrStdout(), "Warn: the flag --kaniko-build-cache is deprecated, use --build-publish-strategy-option KanikoBuildCacheEnabled=true instead")
+		platform.Spec.Build.AddOption(builder.KanikoBuildCacheEnabled, strconv.FormatBool(o.KanikoBuildCache))
+	}
+	if len(o.BuildPublishStrategyOptions) > 0 {
+		if err = o.addBuildPublishStrategyOptions(&platform.Spec.Build); err != nil {
+			return nil, err
+		}
+	}
+	// Always create a platform in the namespace where the operator is located
+	err = install.ObjectOrCollect(o.Context, c, namespace, output, o.Force, platform)
+	if err != nil {
+		return nil, err
+	}
+
+	if err := install.IntegrationPlatformViewerRole(o.Context, c, namespace); err != nil && !k8serrors.IsAlreadyExists(err) {
+		return nil, errors.Wrap(err, "Error while installing global IntegrationPlatform viewer role")
+	}
+
+	if o.ExampleSetup {
+		err = install.ExampleOrCollect(o.Context, c, namespace, output, o.Force)
+		if err != nil {
+			return nil, err
+		}
+	}
+
+	return platform, nil
 }
 
 func (o *installCmdOptions) printOutput(cmd *cobra.Command, collection *kubernetes.Collection) error {
@@ -623,6 +646,21 @@ func (o *installCmdOptions) waitForPlatformReady(cmd *cobra.Command, platform *v
 	return watch.HandlePlatformStateChanges(o.Context, c, platform, handler)
 }
 
+func (o *installCmdOptions) postRun(cmd *cobra.Command, _ []string) error {
+	if o.Save {
+		cfg, err := LoadConfiguration()
+		if err != nil {
+			return err
+		}
+
+		cfg.Update(cmd, pathToRoot(cmd), o, true)
+
+		return cfg.Save()
+	}
+
+	return nil
+}
+
 func (o *installCmdOptions) decode(cmd *cobra.Command, _ []string) error {
 	path := pathToRoot(cmd)
 	if err := decodeKey(o, path); err != nil {
