@@ -21,6 +21,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/pkg/util/camel"
@@ -35,7 +36,6 @@ func TestDependenciesJavaSource(t *testing.T) {
 
 			    from("telegram:bots/cippa").to("log:stash");
 			    from("timer:tick").to("amqp:queue");
-			    from("ine:xistent").to("amqp:queue");
 				from("twitter-search:{{twitterKeywords}}"
                     + "?delay={{twitterDelayMs}}");
 			`,
@@ -44,19 +44,20 @@ func TestDependenciesJavaSource(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:activemq",
-			"camel-quarkus:amqp",
-			"camel-quarkus:log",
-			"camel-quarkus:telegram",
-			"camel-quarkus:timer",
-			"camel-quarkus:twitter",
+			"camel:activemq",
+			"camel:amqp",
+			"camel:log",
+			"camel:telegram",
+			"camel:timer",
+			"camel:twitter",
 		},
 		meta.Dependencies.List())
 }
@@ -70,7 +71,6 @@ func TestDependenciesJavaScript(t *testing.T) {
 
 			    from('telegram:bots/cippa').to("log:stash");
 			    from('timer:tick').to("amqp:queue");
-			    from("ine:xistent").to("amqp:queue");
 			    '"'
 		    `,
 		},
@@ -78,18 +78,19 @@ func TestDependenciesJavaScript(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:activemq",
-			"camel-quarkus:amqp",
-			"camel-quarkus:log",
-			"camel-quarkus:telegram",
-			"camel-quarkus:timer",
+			"camel:activemq",
+			"camel:amqp",
+			"camel:log",
+			"camel:telegram",
+			"camel:timer",
 		},
 		meta.Dependencies.List())
 }
@@ -103,7 +104,6 @@ func TestDependenciesGroovy(t *testing.T) {
 
 			    from('telegram:bots/cippa').to("log:stash");
 			    from('timer:tick').to("amqp:queue");
-			    from("ine:xistent").to("amqp:queue");
 				from('twitter-search:{{twitterKeywords}}'
                     + '?delay={{twitterDelayMs}}');
 			    '"
@@ -113,19 +113,20 @@ func TestDependenciesGroovy(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:activemq",
-			"camel-quarkus:amqp",
-			"camel-quarkus:log",
-			"camel-quarkus:telegram",
-			"camel-quarkus:timer",
-			"camel-quarkus:twitter",
+			"camel:activemq",
+			"camel:amqp",
+			"camel:log",
+			"camel:telegram",
+			"camel:timer",
+			"camel:twitter",
 		},
 		meta.Dependencies.List())
 }
@@ -144,20 +145,42 @@ func TestDependencies(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(t,
 		[]string{
-			"camel-quarkus:http",
-			"camel-quarkus:log",
-			"camel-quarkus:mock",
-			"camel-quarkus:twitter",
+			"camel:http",
+			"camel:log",
+			"camel:mock",
+			"camel:twitter",
 		},
 		meta.Dependencies.List())
 }
 
+func TestDependencyInexistent(t *testing.T) {
+	code := v1.SourceSpec{
+		DataSpec: v1.DataSpec{
+			Name: "Request.java",
+			Content: `
+			    from("http:test").to("log:end");
+			    from("https:test").to("log:end");
+			    from("twitter-timeline:test").to("mock:end");
+			    from("ine:xistent").to("amqp:queue");
+		    `,
+		},
+		Language: v1.LanguageJavaSource,
+	}
+
+	catalog, err := camel.DefaultCatalog()
+	require.NoError(t, err)
+
+	_, err = Extract(catalog, code)
+	assert.Error(t, err)
+}
+
 func TestDependenciesQuarkus(t *testing.T) {
 	code := v1.SourceSpec{
 		DataSpec: v1.DataSpec{
@@ -176,19 +199,20 @@ func TestDependenciesQuarkus(t *testing.T) {
 	}
 
 	catalog, err := camel.QuarkusCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.NotNil(t, catalog)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(t,
 		[]string{
-			"camel-quarkus:http",
-			"camel-quarkus:log",
-			"camel-quarkus:mock",
-			"camel-quarkus:timer",
-			"camel-quarkus:twitter",
-			"camel-quarkus:direct",
+			"camel:http",
+			"camel:log",
+			"camel:mock",
+			"camel:timer",
+			"camel:twitter",
+			"camel:direct",
 		},
 		meta.Dependencies.List())
 
@@ -207,16 +231,17 @@ func TestJacksonDependency(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:http",
-			"camel-quarkus:jackson",
-			"camel-quarkus:log",
+			"camel:http",
+			"camel:jackson",
+			"camel:log",
 		},
 		meta.Dependencies.List())
 }
@@ -235,16 +260,17 @@ func TestJacksonImplicitDependency(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:http",
-			"camel-quarkus:jackson",
-			"camel-quarkus:log",
+			"camel:http",
+			"camel:jackson",
+			"camel:log",
 		},
 		meta.Dependencies.List())
 }
@@ -269,20 +295,21 @@ func TestLanguageDependencies(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:direct",
-			"camel-quarkus:mvel",
-			"camel-quarkus:ognl",
-			"camel-quarkus:xpath",
-			"camel-quarkus:jsonpath",
-			"camel-quarkus:groovy",
-			"camel-quarkus:saxon",
-			"camel-quarkus:xml-jaxp",
+			"camel:direct",
+			"camel:mvel",
+			"camel:ognl",
+			"camel:xpath",
+			"camel:jsonpath",
+			"camel:groovy",
+			"camel:saxon",
+			"camel:stax",
 		},
 		meta.Dependencies.List())
 }
@@ -303,16 +330,17 @@ func TestLanguageDependenciesTransformExpression(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:direct",
-			"camel-quarkus:ognl",
-			"camel-quarkus:xpath",
-			"camel-quarkus:jsonpath",
+			"camel:direct",
+			"camel:ognl",
+			"camel:xpath",
+			"camel:jsonpath",
 		},
 		meta.Dependencies.List())
 }
@@ -333,14 +361,15 @@ func TestCircuitBreakerDependency(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(t,
 		[]string{
-			"camel-quarkus:http",
-			"camel-quarkus:log",
+			"camel:http",
+			"camel:log",
 		},
 		meta.Dependencies.List())
 
@@ -363,18 +392,19 @@ func TestRestDependency(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:http",
-			"camel-quarkus:direct",
-			"camel-quarkus:log",
-			"mvn:org.apache.camel.quarkus/camel-quarkus-rest",
-			"mvn:org.apache.camel.quarkus/camel-quarkus-platform-http",
+			"camel:http",
+			"camel:direct",
+			"camel:log",
+			"mvn:org.apache.camel.quarkus:camel-quarkus-rest",
+			"mvn:org.apache.camel.quarkus:camel-quarkus-platform-http",
 		},
 		meta.Dependencies.List())
 }
@@ -395,17 +425,18 @@ func TestRestWithPathDependency(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t, []string{
-			"camel-quarkus:http",
-			"camel-quarkus:direct",
-			"camel-quarkus:log",
-			"mvn:org.apache.camel.quarkus/camel-quarkus-rest",
-			"mvn:org.apache.camel.quarkus/camel-quarkus-platform-http",
+			"camel:http",
+			"camel:direct",
+			"camel:log",
+			"mvn:org.apache.camel.quarkus:camel-quarkus-rest",
+			"mvn:org.apache.camel.quarkus:camel-quarkus-platform-http",
 		},
 		meta.Dependencies.List())
 }
@@ -425,16 +456,17 @@ func TestRestConfigurationDependency(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t, []string{
-			"camel-quarkus:http",
-			"camel-quarkus:log",
-			"mvn:org.apache.camel.quarkus/camel-quarkus-rest",
-			"mvn:org.apache.camel.quarkus/camel-quarkus-platform-http",
+			"camel:http",
+			"camel:log",
+			"mvn:org.apache.camel.quarkus:camel-quarkus-rest",
+			"mvn:org.apache.camel.quarkus:camel-quarkus-platform-http",
 		},
 		meta.Dependencies.List())
 }
@@ -454,17 +486,18 @@ func TestRestClosureDependencyGroovy(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:http",
-			"camel-quarkus:log",
-			"mvn:org.apache.camel.quarkus/camel-quarkus-rest",
-			"mvn:org.apache.camel.quarkus/camel-quarkus-platform-http",
+			"camel:http",
+			"camel:log",
+			"mvn:org.apache.camel.quarkus:camel-quarkus-rest",
+			"mvn:org.apache.camel.quarkus:camel-quarkus-platform-http",
 		},
 		meta.Dependencies.List())
 }
@@ -484,17 +517,18 @@ func TestRestClosureDependencyKotlin(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:http",
-			"camel-quarkus:log",
-			"mvn:org.apache.camel.quarkus/camel-quarkus-rest",
-			"mvn:org.apache.camel.quarkus/camel-quarkus-platform-http",
+			"camel:http",
+			"camel:log",
+			"mvn:org.apache.camel.quarkus:camel-quarkus-rest",
+			"mvn:org.apache.camel.quarkus:camel-quarkus-platform-http",
 		},
 		meta.Dependencies.List())
 }
@@ -518,16 +552,17 @@ func TestXMLCircuitBreakerDependency(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:direct",
-			"camel-quarkus:kafka",
-			"camel-quarkus:log",
+			"camel:direct",
+			"camel:kafka",
+			"camel:log",
 		},
 		meta.Dependencies.List())
 
@@ -557,15 +592,16 @@ func TestXMLRestDependency(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:direct",
-			"camel-quarkus:mock",
+			"camel:direct",
+			"camel:mock",
 		},
 		meta.Dependencies.List())
 
@@ -614,21 +650,22 @@ func TestXMLLanguageDependencies(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:core",
-			"camel-quarkus:direct",
-			"camel-quarkus:mvel",
-			"camel-quarkus:ognl",
-			"camel-quarkus:xpath",
-			"camel-quarkus:xml-jaxp",
-			"camel-quarkus:jsonpath",
-			"camel-quarkus:saxon",
-			"camel-quarkus:groovy",
+			"camel:core",
+			"camel:direct",
+			"camel:mvel",
+			"camel:ognl",
+			"camel:xpath",
+			"camel:stax",
+			"camel:jsonpath",
+			"camel:saxon",
+			"camel:groovy",
 		},
 		meta.Dependencies.List())
 }
@@ -640,6 +677,7 @@ const yamlWithRest = `
         - to: "log:info"
         - to: "direct:hello"
 `
+
 const yamlWithCircuitBreaker = `
 - from:
     uri: "direct:start"
@@ -683,15 +721,16 @@ func TestYAMLRestDependency(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:direct",
-			"camel-quarkus:log",
+			"camel:direct",
+			"camel:log",
 		},
 		meta.Dependencies.List())
 
@@ -709,14 +748,15 @@ func TestYAMLCircuitBreakerDependency(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:direct",
+			"camel:direct",
 		},
 		meta.Dependencies.List())
 	assert.True(t, meta.RequiredCapabilities.Has(v1.CapabilityCircuitBreaker))
@@ -732,21 +772,22 @@ func TestYAMLLanguageDependencies(t *testing.T) {
 	}
 
 	catalog, err := camel.DefaultCatalog()
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
-	meta := Extract(catalog, code)
+	meta, err := Extract(catalog, code)
+	require.NoError(t, err)
 
 	assert.ElementsMatch(
 		t,
 		[]string{
-			"camel-quarkus:core",
-			"camel-quarkus:direct",
-			"camel-quarkus:ognl",
-			"camel-quarkus:xpath",
-			"camel-quarkus:jsonpath",
-			"camel-quarkus:groovy",
-			"camel-quarkus:saxon",
-			"camel-quarkus:xml-jaxp",
+			"camel:core",
+			"camel:direct",
+			"camel:ognl",
+			"camel:xpath",
+			"camel:jsonpath",
+			"camel:groovy",
+			"camel:saxon",
+			"camel:stax",
 		},
 		meta.Dependencies.List())
 }
