@@ -34,7 +34,7 @@ import (
 )
 
 func TestConfigureEnabledCamelTraitSucceeds(t *testing.T) {
-	trait, environment := createNominalCamelTest()
+	trait, environment := createNominalCamelTest(false)
 
 	configured, err := trait.Configure(environment)
 	assert.Nil(t, err)
@@ -42,7 +42,7 @@ func TestConfigureEnabledCamelTraitSucceeds(t *testing.T) {
 }
 
 func TestConfigureDisabledCamelTraitFails(t *testing.T) {
-	trait, environment := createNominalCamelTest()
+	trait, environment := createNominalCamelTest(false)
 	trait.Enabled = pointer.Bool(false)
 
 	configured, err := trait.Configure(environment)
@@ -51,7 +51,7 @@ func TestConfigureDisabledCamelTraitFails(t *testing.T) {
 }
 
 func TestApplyCamelTraitSucceeds(t *testing.T) {
-	trait, environment := createNominalCamelTest()
+	trait, environment := createNominalCamelTest(false)
 
 	configured, err := trait.Configure(environment)
 	assert.Nil(t, err)
@@ -65,7 +65,7 @@ func TestApplyCamelTraitSucceeds(t *testing.T) {
 }
 
 func TestApplyCamelTraitWithoutEnvironmentCatalogAndUnmatchableVersionFails(t *testing.T) {
-	trait, environment := createNominalCamelTest()
+	trait, environment := createNominalCamelTest(false)
 	environment.CamelCatalog = nil
 	environment.Integration.Status.RuntimeVersion = "Unmatchable version"
 	environment.Integration.Status.RuntimeProvider = v1.RuntimeProviderQuarkus
@@ -79,15 +79,50 @@ func TestApplyCamelTraitWithoutEnvironmentCatalogAndUnmatchableVersionFails(t *t
 	assert.Equal(t, "unable to find catalog matching version requirement: runtime=Unmatchable version, provider=quarkus", err.Error())
 }
 
-func createNominalCamelTest() (*camelTrait, *Environment) {
+func createNominalCamelTest(withSources bool) (*camelTrait, *Environment) {
 	client, _ := test.NewFakeClient()
 
 	trait, _ := newCamelTrait().(*camelTrait)
 	trait.Enabled = pointer.Bool(true)
-
+	var sources []v1.SourceSpec
+	if withSources {
+		sources = []v1.SourceSpec{
+			{
+				DataSpec: v1.DataSpec{
+					Name:    "source1.java",
+					Content: "Java Source Code",
+				},
+				Type: "data",
+			},
+			{
+				DataSpec: v1.DataSpec{
+					Name:    "source2.xml",
+					Content: "XML Source Code",
+				},
+				Type: "data",
+			},
+			{
+				DataSpec: v1.DataSpec{
+					Name:       "source3.xml",
+					ContentRef: "my-cm1",
+				},
+				Type: "data",
+			},
+		}
+	} else {
+		sources = []v1.SourceSpec{}
+	}
 	environment := &Environment{
 		CamelCatalog: &camel.RuntimeCatalog{
 			CamelCatalogSpec: v1.CamelCatalogSpec{
+				Loaders: map[string]v1.CamelLoader{
+					"java": {
+						Metadata: map[string]string{
+							"native":                         "true",
+							"sources-required-at-build-time": "true",
+						},
+					},
+				},
 				Runtime: v1.RuntimeSpec{
 					Version:  "0.0.1",
 					Provider: v1.RuntimeProviderQuarkus,
@@ -99,10 +134,12 @@ func createNominalCamelTest() (*camelTrait, *Environment) {
 		Client:  client,
 		Integration: &v1.Integration{
 			ObjectMeta: metav1.ObjectMeta{
+				Name:      "some-integration",
 				Namespace: "namespace",
 			},
 			Spec: v1.IntegrationSpec{
-				Traits: v1.Traits{},
+				Traits:  v1.Traits{},
+				Sources: sources,
 			},
 			Status: v1.IntegrationStatus{
 				RuntimeVersion: "0.0.1",
@@ -110,6 +147,12 @@ func createNominalCamelTest() (*camelTrait, *Environment) {
 			},
 		},
 		IntegrationKit: &v1.IntegrationKit{
+			ObjectMeta: metav1.ObjectMeta{
+				Labels: map[string]string{
+					v1.IntegrationKitLayoutLabel: v1.IntegrationKitLayoutNative,
+				},
+				Namespace: "namespace",
+			},
 			Status: v1.IntegrationKitStatus{
 				Phase: v1.IntegrationKitPhaseReady,
 			},
@@ -127,7 +170,7 @@ func createNominalCamelTest() (*camelTrait, *Environment) {
 }
 
 func TestApplyCamelTraitWithProperties(t *testing.T) {
-	trait, environment := createNominalCamelTest()
+	trait, environment := createNominalCamelTest(false)
 	trait.Properties = []string{"a=b", "c=d"}
 
 	configured, err := trait.Configure(environment)
@@ -145,3 +188,23 @@ func TestApplyCamelTraitWithProperties(t *testing.T) {
 		"application.properties": "a=b\nc=d\n",
 	}, userPropertiesCm.Data)
 }
+
+func TestApplyCamelTraitWithSources(t *testing.T) {
+	trait, environment := createNominalCamelTest(true)
+
+	configured, err := trait.Configure(environment)
+	assert.Nil(t, err)
+	assert.True(t, configured)
+
+	err = trait.Apply(environment)
+	assert.Nil(t, err)
+
+	assert.Equal(t, 1, environment.Resources.Size())
+	sourceCm := environment.Resources.GetConfigMap(func(cm *corev1.ConfigMap) bool {
+		return cm.Name == "some-integration-source-001" && cm.Annotations["camel.apache.org/source.language"] == "xml" && cm.Annotations["camel.apache.org/source.name"] == "source2.xml"
+	})
+	assert.NotNil(t, sourceCm)
+	assert.Equal(t, map[string]string{
+		"content": "XML Source Code",
+	}, sourceCm.Data)
+}
