@@ -41,9 +41,18 @@ func newTestProbesEnv(t *testing.T, integration *v1.Integration) Environment {
 	traitCatalog := NewCatalog(nil)
 
 	return Environment{
-		Catalog:               traitCatalog,
-		CamelCatalog:          catalog,
-		Platform:              &v1.IntegrationPlatform{},
+		Catalog:      traitCatalog,
+		CamelCatalog: catalog,
+		Platform: &v1.IntegrationPlatform{
+			Status: v1.IntegrationPlatformStatus{
+				Phase: v1.IntegrationPlatformPhaseReady,
+				IntegrationPlatformSpec: v1.IntegrationPlatformSpec{
+					Build: v1.IntegrationPlatformBuildSpec{
+						RuntimeVersion: catalog.Runtime.Version,
+					},
+				},
+			},
+		},
 		Integration:           integration,
 		Resources:             kubernetes.NewCollection(),
 		ApplicationProperties: make(map[string]string),
@@ -54,8 +63,10 @@ func TestProbesDependencies(t *testing.T) {
 	integration := &v1.Integration{
 		Spec: v1.IntegrationSpec{
 			Traits: v1.Traits{
-				Container: &traitv1.ContainerTrait{
-					DeprecatedProbesEnabled: pointer.Bool(true),
+				Health: &traitv1.HealthTrait{
+					Trait: traitv1.Trait{
+						Enabled: pointer.Bool(true),
+					},
 				},
 			},
 		},
@@ -74,10 +85,13 @@ func TestProbesOnDeployment(t *testing.T) {
 	integration := &v1.Integration{
 		Spec: v1.IntegrationSpec{
 			Traits: v1.Traits{
-				Container: &traitv1.ContainerTrait{
-					DeprecatedProbesEnabled:   pointer.Bool(true),
-					Expose:                    pointer.Bool(true),
-					DeprecatedLivenessTimeout: 1234,
+				Health: &traitv1.HealthTrait{
+					Trait: traitv1.Trait{
+						Enabled: pointer.Bool(true),
+					},
+					LivenessProbeEnabled:  pointer.Bool(true),
+					ReadinessProbeEnabled: pointer.Bool(true),
+					LivenessTimeout:       1234,
 				},
 			},
 		},
@@ -106,12 +120,15 @@ func TestProbesOnDeploymentWithCustomScheme(t *testing.T) {
 	integration := &v1.Integration{
 		Spec: v1.IntegrationSpec{
 			Traits: v1.Traits{
-				Container: &traitv1.ContainerTrait{
-					DeprecatedProbesEnabled:   pointer.Bool(true),
-					Expose:                    pointer.Bool(true),
-					DeprecatedLivenessTimeout: 1234,
-					DeprecatedLivenessScheme:  "HTTPS",
-					DeprecatedReadinessScheme: "HTTPS",
+				Health: &traitv1.HealthTrait{
+					Trait: traitv1.Trait{
+						Enabled: pointer.Bool(true),
+					},
+					LivenessProbeEnabled:  pointer.Bool(true),
+					ReadinessProbeEnabled: pointer.Bool(true),
+					LivenessScheme:        "HTTPS",
+					ReadinessScheme:       "HTTPS",
+					LivenessTimeout:       1234,
 				},
 			},
 		},
@@ -146,10 +163,13 @@ func TestProbesOnKnativeService(t *testing.T) {
 						Enabled: pointer.Bool(true),
 					},
 				},
-				Container: &traitv1.ContainerTrait{
-					DeprecatedProbesEnabled:   pointer.Bool(true),
-					Expose:                    pointer.Bool(true),
-					DeprecatedLivenessTimeout: 1234,
+				Health: &traitv1.HealthTrait{
+					Trait: traitv1.Trait{
+						Enabled: pointer.Bool(true),
+					},
+					LivenessProbeEnabled:  pointer.Bool(true),
+					ReadinessProbeEnabled: pointer.Bool(true),
+					LivenessTimeout:       1234,
 				},
 			},
 		},
