@@ -22,40 +22,39 @@ import (
 	"fmt"
 
 	corev1 "k8s.io/api/core/v1"
-	networking "k8s.io/api/networking/v1"
+	networkingv1 "k8s.io/api/networking/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/utils/pointer"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
 )
 
-// The Ingress trait can be used to expose the service associated with the integration
-// to the outside world with a Kubernetes Ingress.
-//
-// It's enabled by default whenever a Service is added to the integration (through the `service` trait).
-//
-// +camel-k:trait=ingress.
 type ingressTrait struct {
-	BaseTrait `property:",squash"`
-	// **Required**. To configure the host exposed by the ingress.
-	Host string `property:"host" json:"host,omitempty"`
-	// To automatically add an ingress whenever the integration uses a HTTP endpoint consumer.
-	Auto *bool `property:"auto" json:"auto,omitempty"`
+	BaseTrait
+	traitv1.IngressTrait `property:",squash"`
 }
 
 func newIngressTrait() Trait {
 	return &ingressTrait{
 		BaseTrait: NewBaseTrait("ingress", 2400),
-		Host:      "",
+		IngressTrait: traitv1.IngressTrait{
+			Host: "",
+		},
 	}
 }
 
 // IsAllowedInProfile overrides default.
 func (t *ingressTrait) IsAllowedInProfile(profile v1.TraitProfile) bool {
-	return profile == v1.TraitProfileKubernetes
+	return profile.Equal(v1.TraitProfileKubernetes)
 }
 
 func (t *ingressTrait) Configure(e *Environment) (bool, error) {
-	if IsFalse(t.Enabled) {
+	if !e.IntegrationInRunningPhases() {
+		return false, nil
+	}
+
+	if !pointer.BoolDeref(t.Enabled, true) {
 		e.Integration.Status.SetCondition(
 			v1.IntegrationConditionExposureAvailable,
 			corev1.ConditionFalse,
@@ -65,38 +64,18 @@ func (t *ingressTrait) Configure(e *Environment) (bool, error) {
 		return false, nil
 	}
 
-	if !e.IntegrationInRunningPhases() {
-		return false, nil
-	}
-
-	if IsNilOrTrue(t.Auto) {
-		hasService := e.Resources.GetUserServiceForIntegration(e.Integration) != nil
-		hasHost := t.Host != ""
-		enabled := hasService && hasHost
-
-		if !enabled {
+	if pointer.BoolDeref(t.Auto, true) {
+		if e.Resources.GetUserServiceForIntegration(e.Integration) == nil {
 			e.Integration.Status.SetCondition(
 				v1.IntegrationConditionExposureAvailable,
 				corev1.ConditionFalse,
 				v1.IntegrationConditionIngressNotAvailableReason,
-				"no host or service defined",
+				"no service defined",
 			)
-
 			return false, nil
 		}
 	}
 
-	if t.Host == "" {
-		e.Integration.Status.SetCondition(
-			v1.IntegrationConditionExposureAvailable,
-			corev1.ConditionFalse,
-			v1.IntegrationConditionIngressNotAvailableReason,
-			"no host defined",
-		)
-
-		return false, errors.New("cannot Apply ingress trait: no host defined")
-	}
-
 	return true, nil
 }
 
@@ -106,27 +85,39 @@ func (t *ingressTrait) Apply(e *Environment) error {
 		return errors.New("cannot Apply ingress trait: no target service")
 	}
 
-	ingress := networking.Ingress{
+	pathType := networkingv1.PathTypePrefix
+
+	ingress := networkingv1.Ingress{
 		TypeMeta: metav1.TypeMeta{
 			Kind:       "Ingress",
-			APIVersion: networking.SchemeGroupVersion.String(),
+			APIVersion: networkingv1.SchemeGroupVersion.String(),
 		},
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      service.Name,
 			Namespace: service.Namespace,
 		},
-		Spec: networking.IngressSpec{
-			DefaultBackend: &networking.IngressBackend{
-				Service: &networking.IngressServiceBackend{
-					Name: service.Name,
-					Port: networking.ServiceBackendPort{
-						Name: "http",
-					},
-				},
-			},
-			Rules: []networking.IngressRule{
+		Spec: networkingv1.IngressSpec{
+			Rules: []networkingv1.IngressRule{
 				{
 					Host: t.Host,
+					IngressRuleValue: networkingv1.IngressRuleValue{
+						HTTP: &networkingv1.HTTPIngressRuleValue{
+							Paths: []networkingv1.HTTPIngressPath{
+								{
+									Path:     "/",
+									PathType: &pathType,
+									Backend: networkingv1.IngressBackend{
+										Service: &networkingv1.IngressServiceBackend{
+											Name: service.Name,
+											Port: networkingv1.ServiceBackendPort{
+												Name: "http",
+											},
+										},
+									},
+								},
+							},
+						},
+					},
 				},
 			},
 		},
@@ -134,11 +125,7 @@ func (t *ingressTrait) Apply(e *Environment) error {
 
 	e.Resources.Add(&ingress)
 
-	message := fmt.Sprintf("%s(%s) -> %s(%s)",
-		ingress.Name,
-		t.Host,
-		ingress.Spec.DefaultBackend.Service.Name,
-		ingress.Spec.DefaultBackend.Service.Port.Name)
+	message := fmt.Sprintf("%s(%s) -> %s(%s)", ingress.Name, t.Host, service.Name, "http")
 
 	e.Integration.Status.SetCondition(
 		v1.IntegrationConditionExposureAvailable,
