@@ -21,6 +21,7 @@ import (
 	"context"
 	"fmt"
 	"path"
+	"path/filepath"
 	"sort"
 	"strings"
 
@@ -404,32 +405,36 @@ func (e *Environment) addSourcesProperties() {
 	if e.ApplicationProperties == nil {
 		e.ApplicationProperties = make(map[string]string)
 	}
-	for i, s := range e.Integration.Sources() {
-		srcName := strings.TrimPrefix(s.Name, "/")
-		src := "file:" + path.Join(camel.SourcesMountPath, srcName)
-		e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].location", i)] = src
+	idx := 0
+	for _, s := range e.Integration.Sources() {
+		if e.isEmbedded(s) {
+			continue
+		}
+		srcName := strings.TrimPrefix(filepath.ToSlash(s.Name), "/")
+		src := "file:" + path.Join(filepath.ToSlash(camel.SourcesMountPath), srcName)
+		e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].location", idx)] = src
 
 		simpleName := srcName
 		if strings.Contains(srcName, ".") {
 			simpleName = srcName[0:strings.Index(srcName, ".")]
 		}
-		e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].name", i)] = simpleName
+		e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].name", idx)] = simpleName
 
 		for pid, p := range s.PropertyNames {
-			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].property-names[%d]", i, pid)] = p
+			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].property-names[%d]", idx, pid)] = p
 		}
 
 		if s.Type != "" {
-			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].type", i)] = string(s.Type)
+			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].type", idx)] = string(s.Type)
 		}
 		if s.InferLanguage() != "" {
-			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].language", i)] = string(s.InferLanguage())
+			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].language", idx)] = string(s.InferLanguage())
 		}
 		if s.Loader != "" {
-			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].loader", i)] = s.Loader
+			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].loader", idx)] = s.Loader
 		}
 		if s.Compression {
-			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].compressed", i)] = "true"
+			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].compressed", idx)] = "true"
 		}
 
 		interceptors := make([]string, 0, len(s.Interceptors))
@@ -440,8 +445,9 @@ func (e *Environment) addSourcesProperties() {
 			interceptors = append(interceptors, e.Interceptors...)
 		}
 		for intID, interceptor := range interceptors {
-			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].interceptors[%d]", i, intID)] = interceptor
+			e.ApplicationProperties[fmt.Sprintf("camel.k.sources[%d].interceptors[%d]", idx, intID)] = interceptor
 		}
+		idx++
 	}
 }
 
@@ -449,8 +455,12 @@ func (e *Environment) configureVolumesAndMounts(vols *[]corev1.Volume, mnts *[]c
 	//
 	// Volumes :: Sources
 	//
-	for i, s := range e.Integration.Sources() {
-		cmName := fmt.Sprintf("%s-source-%03d", e.Integration.Name, i)
+	idx := 0
+	for _, s := range e.Integration.Sources() {
+		if e.isEmbedded(s) {
+			continue
+		}
+		cmName := fmt.Sprintf("%s-source-%03d", e.Integration.Name, idx)
 		if s.ContentRef != "" {
 			cmName = s.ContentRef
 		}
@@ -459,13 +469,14 @@ func (e *Environment) configureVolumesAndMounts(vols *[]corev1.Volume, mnts *[]c
 			cmKey = s.ContentKey
 		}
 		resName := strings.TrimPrefix(s.Name, "/")
-		refName := fmt.Sprintf("i-source-%03d", i)
-		resPath := path.Join(camel.SourcesMountPath, resName)
+		refName := fmt.Sprintf("i-source-%03d", idx)
+		resPath := filepath.Join(camel.SourcesMountPath, resName)
 		vol := getVolume(refName, "configmap", cmName, cmKey, resName)
 		mnt := getMount(refName, resPath, resName, true)
 
 		*vols = append(*vols, *vol)
 		*mnts = append(*mnts, *mnt)
+		idx++
 	}
 
 	if e.Resources != nil {
@@ -476,9 +487,9 @@ func (e *Environment) configureVolumesAndMounts(vols *[]corev1.Volume, mnts *[]c
 			var mountPath string
 			switch propertiesType {
 			case "application":
-				mountPath = path.Join(camel.BasePath, resName)
+				mountPath = filepath.Join(camel.BasePath, resName)
 			case "user":
-				mountPath = path.Join(camel.ConfDPath, resName)
+				mountPath = filepath.Join(camel.ConfDPath, resName)
 			}
 
 			if propertiesType != "" {
@@ -521,7 +532,7 @@ func (e *Environment) configureVolumesAndMounts(vols *[]corev1.Volume, mnts *[]c
 	if len(e.ServiceBindingSecret) > 0 {
 		secret := e.ServiceBindingSecret
 		refName := kubernetes.SanitizeLabel(secret)
-		mountPath := path.Join(camel.ServiceBindingsMountPath, strings.ToLower(secret))
+		mountPath := filepath.Join(camel.ServiceBindingsMountPath, strings.ToLower(secret))
 		vol := getVolume(refName, "secret", secret, "", "")
 		mnt := getMount(refName, mountPath, "", true)
 
@@ -613,14 +624,14 @@ func getMountPoint(resourceName string, mountPoint string, storagetype, resource
 		return mountPoint
 	}
 	if resourceType == "data" {
-		return path.Join(camel.ResourcesDefaultMountPath, resourceName)
+		return filepath.Join(camel.ResourcesDefaultMountPath, resourceName)
 	}
 	defaultMountPoint := camel.ConfigConfigmapsMountPath
 	if storagetype == "secret" {
 		defaultMountPoint = camel.ConfigSecretsMountPath
 	}
 
-	return path.Join(defaultMountPoint, resourceName)
+	return filepath.Join(defaultMountPoint, resourceName)
 }
 
 func (e *Environment) collectConfigurationValues(configurationType string) []string {
@@ -650,6 +661,16 @@ func (e *Environment) GetIntegrationContainerName() string {
 	return containerName
 }
 
+// Indicates whether the given source is embedded in the final binary.
+func (e *Environment) isEmbedded(source v1.SourceSpec) bool {
+	if dt := e.Catalog.GetTrait(quarkusTraitID); dt != nil {
+		if qt, ok := dt.(*quarkusTrait); ok {
+			return qt.isEmbedded(e, source)
+		}
+	}
+	return false
+}
+
 func (e *Environment) GetIntegrationContainer() *corev1.Container {
 	containerName := e.GetIntegrationContainerName()
 	return e.Resources.GetContainerByName(containerName)
